==> modx-2.0.5-pl-ja.zip: modx-2.0.5-pl-ja/core/lexicon/ja/template.inc.php <==
<?php
/**
 * Template Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['access'] = 'アクセス';
$_lang['rank'] = 'ランク';
$_lang['template'] = 'テンプレート';
$_lang['template_assignedtv_tab'] = '指定されているテンプレート変数';
$_lang['template_code'] = 'テンプレート コード (html)';
$_lang['template_desc'] = '説明';
$_lang['template_delete_confirm'] = 'このテンプレートを削除しますか？';
$_lang['template_duplicate_confirm'] = 'このテンプレートを複製しますか？';
$_lang['template_edit_tab'] = 'テンプレートの編集';
$_lang['template_empty'] = '(empty)';
$_lang['template_err_default_template'] = 'このテンプレートは既定のテンプレートとして設定されています。削除する前に、別なテンプレートを既定のテンプレートとして設定してください。<br />';
$_lang['template_err_delete'] = 'テンプレートの削除中にエラーが発生しました。';
$_lang['template_err_duplicate'] = 'テンプレートの複製中にエラーが発生しました。';
$_lang['template_err_exists_name'] = '[[+name]]という名前のテンプレートがすでに存在します。';
$_lang['template_err_in_use'] = 'このテンプレートは使用中です。このテンプレートを利用しているドキュメントの設定を変え、別なテンプレートを利用するようにしてください。このテンプレートを使用しているドキュメントは:<br />';
$_lang['template_err_locked'] = 'テンプレートは編集中のためロックされています。';
$_lang['template_err_nf'] = 'テンプレートが見つかりません。';
$_lang['template_err_ns'] = 'テンプレートが指定されていません。';
$_lang['template_err_ns_name'] = 'テンプレートの名前を指定してください。';
$_lang['template_err_remove'] = 'テンプレートの削除中にエラーが発生しました。';
$_lang['template_err_save'] = 'テンプレートの保存中にエラーが発生しました。';
$_lang['template_lock'] = 'テンプレート編集をロック';
$_lang['template_lock_msg'] = 'このテンプレートを編集するためにはロックを解除する必要があります。';
$_lang['template_locked_message'] = 'このテンプレートはロックされています';
$_lang['template_management_msg'] = '<h3 style="font-weight:bold;">テンプレートデザインの管理</h3><p>テンプレートはいくつでも作成でき、ドキュメントごとに自由に割り当てることができます。</p>';
$_lang['template_msg'] = 'テンプレートを作成/編集します。';
$_lang['template_name'] = 'テンプレート名';
$_lang['template_new'] = '新しいテンプレート';
$_lang['template_no_tv'] = 'テンプレート変数は指定されていません。';
$_lang['template_properties'] = '既定のプロパティ';
$_lang['template_reset_all'] = '全てのドキュメントが既定のテンプレートを使用するようにリセットする';
$_lang['template_reset_specific'] = '「%s」を使用しているドキュメントのみリセットする';
$_lang['template_title'] = 'テンプレートの作成/編集';
$_lang['template_tv_edit'] = 'テンプレート変数の順序を書き換え';
$_lang['template_tv_msg'] = 'このテンプレートに指定されているテンプレート変数は下記のリストのとおりです。';
$_lang['template_untitled'] = '無名のテンプレート';
$_lang['templates'] = 'テンプレート';
$_lang['tvt_err_nf'] = 'テンプレート変数は、そのテンプレートに対するアクセス権がありません。';
$_lang['tvt_err_remove'] = 'テンプレートからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvt_err_save'] = 'テンプレートにテンプレート変数を紐付け中にエラーが発生しました。';

==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/template.inc.php <==
<?php
/**
 * Template Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['access'] = 'アクセス';
$_lang['filter_by_category'] = 'Filter by Category...';
$_lang['rank'] = 'ランク';
$_lang['template'] = 'テンプレート';
$_lang['template_assignedtv_tab'] = '指定されているテンプレート変数';
$_lang['template_code'] = 'テンプレート コード (html)';
$_lang['template_desc'] = '説明';
$_lang['template_desc_category'] = 'このテンプレートが属するカテゴリー';
$_lang['template_desc_description'] = 'このテンプレートの簡単な説明.';
$_lang['template_desc_name'] = 'The name of this Template.';
$_lang['template_delete_confirm'] = 'このテンプレートを削除しますか？';
$_lang['template_duplicate_confirm'] = 'このテンプレートを複製しますか？';
$_lang['template_edit_tab'] = 'テンプレートの編集';
$_lang['template_empty'] = '(empty)';
$_lang['template_err_default_template'] = 'このテンプレートは既定のテンプレートとして設定されています。削除する前に、別なテンプレートを既定のテンプレートとして設定してください。<br />';
$_lang['template_err_delete'] = 'テンプレートの削除中にエラーが発生しました。';
$_lang['template_err_duplicate'] = 'テンプレートの複製中にエラーが発生しました。';
$_lang['template_err_exists_name'] = '[[+name]]という名前のテンプレートがすでに存在します。';
$_lang['template_err_in_use'] = 'このテンプレートは使用中です。このテンプレートを利用しているドキュメントの設定を変え、別なテンプレートを利用するようにしてください。このテンプレートを使用しているドキュメントは:<br />';
$_lang['template_err_locked'] = 'テンプレートは編集中のためロックされています。';
$_lang['template_err_nf'] = 'テンプレートが見つかりません。';
$_lang['template_err_ns'] = 'テンプレートが指定されていません。';
$_lang['template_err_ns_name'] = 'テンプレートの名前を指定してください。';
$_lang['template_err_remove'] = 'テンプレートの削除中にエラーが発生しました。';
$_lang['template_err_save'] = 'テンプレートの保存中にエラーが発生しました。';
$_lang['template_lock'] = 'テンプレート編集をロック';
$_lang['template_lock_msg'] = 'このテンプレートを編集するためにはロックを解除する必要があります。';
$_lang['template_locked_message'] = 'このテンプレートはロックされています';
$_lang['template_management_msg'] = '<h3 style="font-weight:bold;">テンプレートデザインの管理</h3><p>テンプレートはいくつでも作成でき、ドキュメントごとに自由に割り当てることができます。</p>';
$_lang['template_msg'] = 'テンプレートを作成/編集します。';
$_lang['template_name'] = 'テンプレート名';
$_lang['template_new'] = '新しいテンプレート';
$_lang['template_no_tv'] = 'テンプレート変数は指定されていません。';
$_lang['template_properties'] = '既定のプロパティ';
$_lang['template_reset_all'] = '全てのドキュメントが既定のテンプレートを使用するようにリセットする';
$_lang['template_reset_specific'] = '「%s」を使用しているドキュメントのみリセットする';
$_lang['template_title'] = 'テンプレートの作成/編集';
$_lang['template_tv_edit'] = 'テンプレート変数の順序を書き換え';
$_lang['template_tv_msg'] = 'このテンプレートに指定されているテンプレート変数は下記のリストのとおりです。';
$_lang['template_untitled'] = '無名のテンプレート';
$_lang['templates'] = 'テンプレート';
$_lang['tvt_err_nf'] = 'テンプレート変数は、そのテンプレートに対するアクセス権がありません。';
$_lang['tvt_err_remove'] = 'テンプレートからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvt_err_save'] = 'テンプレートにテンプレート変数を紐付け中にエラーが発生しました。';
